elfcheck

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package elfcheck validates that an output file is a well-formed eBPF ELF object.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Validate

func Validate(path string) error

Validate opens the ELF at path and checks that it meets the minimum requirements for a BPF object: 64-bit class, EM_BPF machine, at least one executable program section, and at least one symbol.

Types

This section is empty.

Jump to